@@ -9,6 +9,7 @@ import tempfile
 import os
 import urllib
 import logging
+import uuid
 
 from jss.connection import JssClient
 
@@ -138,7 +139,8 @@ class Storage(driver.Base):
             part_size = self.buffer_size
         
         try:
-            tmp_file = tempfile.mktemp(suffix=path1, prefix='docker_registry_image', dir="/tmp")
+            tmp_dir = "/tmp/"+uuid.uuid1()
+            tmp_file = tempfile.mktemp(suffix=path1, prefix='docker_registry_image', dir=tmp_dir)
             with open(tmp_file, 'w') as f:
                 while True:
                     buf = fp.read(part_size)
